@@ -3,6 +3,7 @@ CLI interface for deprecated dependencies checker.
 """
 
 import sys
+import yaml
 from pathlib import Path
 from typing import Optional
 import typer
@@ -18,6 +19,7 @@ sys.path.insert(0, str(Path(__file__).parent.parent))
 from core.checker import DeprecatedChecker
 from core.data_collector import DataCollector
 from core.scheduler import DatabaseScheduler, ManualUpdater, UpdateConfig
+from core.repository_analyzer import RepositoryAnalyzer
 
 
 app = typer.Typer(
@@ -192,37 +194,47 @@ def display_text_report(result, checker, verbose: bool):
 @app.command()
 def list_db():
     """Shows all deprecated packages in the database."""
-    checker = DeprecatedChecker()
-    db = checker.db
-    
-    deprecated_packages = db.get_all_deprecated_packages()
-    
-    if not deprecated_packages:
-        console.print("[yellow]Database is empty[/yellow]")
-        return
-    
-    table = Table(
-        title="Deprecated packages in database",
-        show_header=True,
-        header_style="bold magenta"
-    )
-    table.add_column("Package", style="cyan")
-    table.add_column("Deprecated since", style="red")
-    table.add_column("Reason", style="yellow")
-    table.add_column("Alternatives", style="green")
-    
-    for package_name in deprecated_packages:
-        info = db.get_deprecated_info(package_name)
-        alternatives = [alt["name"] for alt in info.get("alternatives", [])]
+    try:
+        from core.database import DeprecatedPackageDB
+        db = DeprecatedPackageDB()
         
-        table.add_row(
-            package_name,
-            info.get("deprecated_since", "unknown"),
-            info.get("reason", "not specified"),
-            ", ".join(alternatives) if alternatives else "none"
+        if not db.data:
+            console.print("[yellow]Database is empty[/yellow]")
+            return
+        
+        # Create table
+        table = Table(
+            title="Deprecated packages in database",
+            show_header=True,
+            header_style="bold magenta"
         )
-    
-    console.print(table)
+        table.add_column("Package", style="cyan")
+        table.add_column("Deprecated since", style="red")
+        table.add_column("Reason", style="yellow")
+        table.add_column("Alternatives", style="green")
+        
+        # Add data
+        for package_name, package_data in db.data.items():
+            deprecated_since = package_data.get("deprecated_since", "unknown")
+            reason = package_data.get("reason", "not specified")
+            alternatives = package_data.get("alternatives", [])
+            
+            # Format alternatives
+            alt_names = [alt.get("name", "") for alt in alternatives]
+            alternatives_str = ", ".join(alt_names) if alt_names else "none"
+            
+            table.add_row(
+                package_name,
+                deprecated_since,
+                reason,
+                alternatives_str
+            )
+        
+        console.print(table)
+        
+    except Exception as e:
+        console.print(f"[red]Error: {e}[/red]")
+        sys.exit(1)
 
 
 @app.command()
@@ -252,6 +264,81 @@ def search(
                 console.print(f"    Guide: {alt['migration_guide']}")
 
 
+@app.command()
+def analyze_repository(
+    path: Optional[Path] = typer.Option(
+        None,
+        "--path", "-p",
+        help="Path to project for analysis (default: current directory)"
+    ),
+    save: bool = typer.Option(
+        False,
+        "--save", "-s",
+        help="Save analysis results to cache"
+    )
+):
+    """Analyzes repository dependencies and builds dynamic database."""
+    
+    # Define project path
+    project_path = path or Path.cwd()
+    
+    if not project_path.exists():
+        console.print(f"[red]Error: Path {project_path} does not exist[/red]")
+        sys.exit(1)
+    
+    # Show progress
+    with Progress(
+        SpinnerColumn(),
+        TextColumn("[progress.description]{task.description}"),
+        console=console
+    ) as progress:
+        task = progress.add_task("Analyzing repository dependencies...", total=None)
+        
+        try:
+            # Create analyzer and analyze repository
+            analyzer = RepositoryAnalyzer()
+            database = analyzer.analyze_repository(project_path)
+            
+            progress.update(task, description="Generating report...")
+            
+            # Display results
+            if database:
+                console.print(f"[green]✓ Analysis complete! Found {len(database)} deprecated packages[/green]")
+                
+                # Create table
+                table = Table(title="Repository Analysis Results")
+                table.add_column("Package", style="cyan")
+                table.add_column("Deprecated since", style="green")
+                table.add_column("Reason", style="yellow")
+                table.add_column("Source", style="blue")
+                
+                # Add data
+                for package_name, package_data in database.items():
+                    deprecated_since = package_data.get("deprecated_since", "unknown")
+                    reason = package_data.get("reason", "not specified")
+                    source = package_data.get("source", "unknown")
+                    
+                    table.add_row(
+                        package_name,
+                        deprecated_since,
+                        reason,
+                        source
+                    )
+                
+                console.print(table)
+                
+                # Save if requested
+                if save:
+                    analyzer.save_database(database)
+                    console.print("[green]✓ Analysis results saved to cache[/green]")
+            else:
+                console.print("[yellow]No deprecated packages found in repository[/yellow]")
+                
+        except Exception as e:
+            console.print(f"[red]Error: {e}[/red]")
+            sys.exit(1)
+
+
 @app.command()
 def update_db(
     source: Optional[str] = typer.Option(
@@ -263,6 +350,11 @@ def update_db(
         False,
         "--force", "-f",
         help="Force immediate update"
+    ),
+    comprehensive: bool = typer.Option(
+        False,
+        "--comprehensive", "-c",
+        help="Perform comprehensive update with all known packages"
     )
 ):
     """Updates the deprecated packages database."""
@@ -272,7 +364,45 @@ def update_db(
         console.print("Available sources: pypi, manual, github, security_advisories, all")
         return
     
-    if source == "all" or source is None:
+    if comprehensive:
+        console.print("[yellow]Starting comprehensive database update...[/yellow]")
+        console.print("This will check hundreds of packages and may take several minutes.")
+        
+        with Progress(
+            SpinnerColumn(),
+            TextColumn("[progress.description]{task.description}"),
+            console=console
+        ) as progress:
+            task = progress.add_task("Updating comprehensive database...", total=None)
+            
+            try:
+                # Create comprehensive collector
+                collector = DataCollector()
+                all_data = collector.collect_all_data()
+                
+                # Save comprehensive database
+                output_path = Path.cwd() / "data" / "comprehensive_deprecated_packages.yaml"
+                output_path.parent.mkdir(exist_ok=True)
+                
+                with open(output_path, 'w', encoding='utf-8') as f:
+                    yaml.dump(all_data, f, default_flow_style=False, allow_unicode=True)
+                
+                console.print(f"[green]✓ Comprehensive database updated successfully![/green]")
+                console.print(f"[green]Found {len(all_data)} deprecated packages[/green]")
+                console.print(f"[green]Saved to: {output_path}[/green]")
+                
+                # Show statistics
+                stats = collector.get_statistics()
+                console.print(f"\n[blue]Statistics:[/blue]")
+                console.print(f"  Total packages checked: {stats.get('total_packages', 'unknown')}")
+                console.print(f"  Deprecated packages found: {len(all_data)}")
+                console.print(f"  Sources used: {', '.join(stats.get('sources', []))}")
+                
+            except Exception as e:
+                console.print(f"[red]Error during comprehensive update: {e}[/red]")
+                sys.exit(1)
+    
+    elif source == "all" or source is None:
         # Update from all sources
         console.print("Updating database from all sources...")
         collector = DataCollector()
@@ -359,16 +489,35 @@ def validate_db():
 @app.command()
 def stats():
     """Shows database statistics."""
-    console.print("Database Statistics:")
-    
-    collector = DataCollector()
-    stats = collector.get_statistics()
-    
-    console.print(f"Total packages: {stats['total_packages']}")
-    console.print("Sources:")
-    for source, count in stats["sources"].items():
-        console.print(f"  {source}: {count} packages")
-    console.print(f"Last updated: {stats.get('last_updated', 'Unknown')}")
+    try:
+        from core.database import DeprecatedPackageDB
+        db = DeprecatedPackageDB()
+        
+        console.print("Database Statistics:")
+        console.print(f"Total packages: {len(db.data)}")
+        
+        # Count by source
+        sources = {}
+        for package_data in db.data.values():
+            source = package_data.get("source", "unknown")
+            sources[source] = sources.get(source, 0) + 1
+        
+        console.print("Sources:")
+        for source, count in sources.items():
+            console.print(f"  {source}: {count} packages")
+        
+        # Get last updated
+        last_updated = None
+        for package_data in db.data.values():
+            package_updated = package_data.get("last_updated")
+            if package_updated and (last_updated is None or package_updated > last_updated):
+                last_updated = package_updated
+        
+        console.print(f"Last updated: {last_updated or 'Unknown'}")
+        
+    except Exception as e:
+        console.print(f"[red]Error: {e}[/red]")
+        sys.exit(1)
 
 
 @app.command()
